"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
class Cookie {
    constructor(value) {
        this.value = value;
    }
    secureCookie(options) {
        options = utils_1.parseCookieOptions(options);
        let cookie_value;
        cookie_value = `${this.value}; Path=${options.path}`;
        if (options.secure) {
            cookie_value += "; Secure";
        }
        if (options.httpOnly) {
            cookie_value += "; HttpOnly";
        }
        if (options.sameSite) {
            const sameSiteValue = utils_1.sameSiteOptions(options.sameSite);
            cookie_value += `; SameSite=${sameSiteValue}`;
        }
        if (options.expires) {
            if (typeof options.expires == "number") {
                cookie_value += `; Expires=${cookieExpiration(options.expires)}`;
            }
        }
        return cookie_value;
    }
}
exports.Cookie = Cookie;
function cookieExpiration(hours, dateObject = false) {
    const dateNow = new Date();
    let returnObject;
    dateNow.setHours(dateNow.getHours() + hours);
    let expire_time = dateNow.toUTCString();
    if (dateObject) {
        returnObject = dateNow;
    }
    else {
        returnObject = expire_time;
    }
    return returnObject;
}
function commonCookieOptions(options) {
    options = utils_1.parseCookieOptions(options);
    const cookieOptions = {
        httpOnly: options.httpOnly,
        path: options.path,
        secure: options.secure
    };
    if (options.expires) {
        if (typeof options.expires == "number") {
            const expireDate = new Date();
            expireDate.setHours(expireDate.getHours() + options.expires);
            cookieOptions.expires = expireDate;
        }
    }
    if (options.sameSite) {
        const sameSiteValue = utils_1.sameSiteOptions(options.sameSite);
        cookieOptions.sameSite = sameSiteValue;
    }
    return cookieOptions;
}
exports.commonCookieOptions = commonCookieOptions;
function setCommonCookie(res, name, value, options) {
    const cookieOptions = commonCookieOptions(options);
    res.cookie(name, value, cookieOptions);
}
exports.setCommonCookie = setCommonCookie;
