"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const cookie_1 = require("./cookie");
class SecureCookie {
    constructor(options) {
        this.options = options;
    }
    adonis(response, name, value) {
        cookie_1.setCommonCookie(response, name, value, this.options);
    }
    express(res, name, value) {
        cookie_1.setCommonCookie(res, name, value, this.options);
    }
    fastify(res, name, value) {
        const cookieValue = new cookie_1.Cookie(value).secureCookie(this.options);
        res.header("Set-Cookie", `${name}=${cookieValue}`);
    }
    hapi(h, name, value) {
        const options = utils_1.parseCookieOptions(this.options);
        const cookieOptions = {
            isSecure: options.secure,
            isHttpOnly: options.httpOnly,
            path: options.path
        };
        if (options.expires) {
            if (typeof options.expires == "number") {
                const expireMilliseconds = options.expires * 60 * 60 * 1000;
                cookieOptions.ttl = expireMilliseconds;
            }
        }
        if (options.sameSite) {
            const sameSiteValue = utils_1.sameSiteOptions(options.sameSite);
            cookieOptions.isSameSite = sameSiteValue;
        }
        h.state(name, value, cookieOptions);
    }
    koa(ctx, name, value) {
        const options = utils_1.parseCookieOptions(this.options);
        const cookieOptions = cookie_1.commonCookieOptions(options);
        ctx.cookies.set(name, value, cookieOptions);
    }
    polka(res, name, value) {
        const cookieValue = new cookie_1.Cookie(value).secureCookie(this.options);
        res.setHeader("Set-Cookie", `${name}=${cookieValue}`);
    }
    nest(res, name, value) {
        cookie_1.setCommonCookie(res, name, value, this.options);
    }
    restify(res, name, value) {
        const cookieValue = new cookie_1.Cookie(value).secureCookie(this.options);
        res.header("Set-Cookie", `${name}=${cookieValue}`);
    }
    sails(res, name, value) {
        cookie_1.setCommonCookie(res, name, value, this.options);
    }
    total(res, name, value) {
        cookie_1.setCommonCookie(res, name, value, this.options);
    }
}
exports.SecureCookie = SecureCookie;
