export declare enum PolicyOptions {
    NotSet = 0,
    DefaultHeader = 1,
    CustomValue = 2
}
export declare class Content {
    policy?: string;
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare class CSP {
    policy: HeaderOptions[];
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    baseUri(...sources: string[]): this;
    blockAllMixedContent(): this;
    connectSrc(...sources: string[]): this;
    defaultSrc(...sources: string[]): this;
    fontSrc(...sources: string[]): this;
    formAction(...sources: string[]): this;
    frameAncestors(...sources: string[]): this;
    frameSrc(...sources: string[]): this;
    imgSrc(...sources: string[]): this;
    manifestSrc(...sources: string[]): this;
    mediaSrc(...sources: string[]): this;
    objectSrc(...sources: string[]): this;
    pluginTypes(...types: string[]): Window;
    requireSriFor(...values: string[]): this;
    reportTo(json_object: object): this;
    reportUri(uri: string): this;
    sandbox(...values: string[]): this;
    scriptSrc(...sources: string[]): this;
    styleSrc(...sources: string[]): Window;
    upgradeInsecureRequests(): Window;
    workerSrc(...sources: string[]): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare class XFO {
    policy?: string;
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    allowFrom(uri: string): this;
    deny(): this;
    sameorigin(): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare class XXP {
    policy?: string;
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    disabled(): this;
    enabled(): this;
    enabledBlock(): this;
    enabledReport(uri: string): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare class Referrer {
    policy: string[];
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    noReferrer(): this;
    noReferrerWhenDowngrade(): this;
    origin(): this;
    originWhenCrossOrigin(): this;
    sameOrigin(): this;
    strictOrigin(): this;
    strictOriginWhenCrossOrigin(): this;
    unsafeUrl(): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare class HSTS {
    policy: string[];
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    includeSubdomains(): this;
    maxAge(seconds: string): this;
    preload(): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare class Cache {
    policy: string[];
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    immutable(): this;
    maxAge(seconds: string): this;
    maxStale(seconds: string): this;
    minFresh(seconds: string): this;
    mustRevalidate(): this;
    noCache(): this;
    noStore(): this;
    noTransform(): this;
    onlyIfCached(): this;
    private(): this;
    proxyRevalidate(): this;
    public(): this;
    sMaxage(seconds: string): this;
    staleIfError(seconds: string): this;
    staleWhileRevalidate(seconds: string): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare class Feature {
    policy: HeaderOptions[];
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    accelerometer(...allowlist: string[]): this;
    ambientLightSensor(...allowlist: string[]): this;
    autoplay(...allowlist: string[]): this;
    camera(...allowlist: string[]): this;
    documentDomain(...allowlist: string[]): this;
    encryptedMedia(...allowlist: string[]): this;
    fullscreen(...allowlist: string[]): this;
    geolocation(...allowlist: string[]): this;
    gyroscope(...allowlist: string[]): this;
    magnetometer(...allowlist: string[]): this;
    microphone(...allowlist: string[]): this;
    midi(...allowlist: string[]): this;
    payment(...allowlist: string[]): this;
    pictureInPicture(...allowlist: string[]): this;
    speaker(...allowlist: string[]): this;
    syncXhr(...allowlist: string[]): this;
    usb(...allowlist: string[]): this;
    vibrate(...allowlist: string[]): this;
    vr(...allowlist: string[]): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare class Server {
    policy?: string;
    custom?: string;
    optionType: PolicyOptions;
    default(): this;
    notSet(): this;
    set(value: string): this;
    readonly value: string | undefined;
    readonly option: PolicyOptions;
}
export declare const values: {
    all: string;
    none: string;
    self: string;
    src: string;
    strictDynamic: string;
    unsafeEval: string;
    unsafeInline: string;
};
export declare const seconds: {
    fiveMinutes: string;
    oneWeek: string;
    oneMonth: string;
    oneYear: string;
    twoYears: string;
};
interface HeaderOptions {
    directive: string;
    sources?: string[] | string | object;
}
export {};
