"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const policies_1 = require("./policies");
const cookieOptions = {
    path: "/",
    secure: true,
    httpOnly: true,
    sameSite: { value: "Lax" },
    expires: false
};
const headerOptions = {
    server: new policies_1.Server().notSet(),
    hsts: new policies_1.HSTS().default(),
    xfo: new policies_1.XFO().default(),
    xxp: new policies_1.XXP().default(),
    content: new policies_1.Content().default(),
    csp: new policies_1.CSP().notSet(),
    referrer: new policies_1.Referrer().default(),
    cache: new policies_1.Cache().default(),
    feature: new policies_1.Feature().notSet()
};
function parseHeaderOptions(options) {
    const defaultOptions = headerOptions;
    for (let property in options) {
        if (options.hasOwnProperty(property)) {
            defaultOptions[property] = options[property];
        }
    }
    return defaultOptions;
}
exports.parseHeaderOptions = parseHeaderOptions;
function parseCookieOptions(options) {
    const defaultOptions = cookieOptions;
    for (let property in options) {
        if (options.hasOwnProperty(property)) {
            defaultOptions[property] = options[property];
        }
    }
    return defaultOptions;
}
exports.parseCookieOptions = parseCookieOptions;
function sameSiteOptions(option) {
    switch (option.value) {
        case "Lax":
            return "Lax";
        case "Strict":
            return "Strict";
        case 0:
            return false;
    }
}
exports.sameSiteOptions = sameSiteOptions;
